from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_user_create_api_key_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
)
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_user_create_api_key_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse,
)
from ...types import Response


def _get_kwargs(
    *,
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api_keys",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    if response.status_code == 201:
        response_201 = GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse.from_dict(response.json())

        return response_201
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    """Create API Key

      Endpoint for creating a new API key with a user-provided public key.  This endpoint allows users
    with Premier or Market Maker API usage levels to create API keys by providing their own RSA public
    key. The platform will use this public key to verify signatures on API requests.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    """Create API Key

      Endpoint for creating a new API key with a user-provided public key.  This endpoint allows users
    with Premier or Market Maker API usage levels to create API keys by providing their own RSA public
    key. The platform will use this public key to verify signatures on API requests.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    """Create API Key

      Endpoint for creating a new API key with a user-provided public key.  This endpoint allows users
    with Premier or Market Maker API usage levels to create API keys by providing their own RSA public
    key. The platform will use this public key to verify signatures on API requests.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse]:
    """Create API Key

      Endpoint for creating a new API key with a user-provided public key.  This endpoint allows users
    with Premier or Market Maker API usage levels to create API keys by providing their own RSA public
    key. The platform will use this public key to verify signatures on API requests.

    Args:
        body (GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelUserCreateApiKeyResponse
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request_accepted_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest:
    """
    Attributes:
        accepted_side (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide]): The side
            of the quote to accept (yes or no).
    """

    accepted_side: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        accepted_side: Union[Unset, str] = UNSET
        if not isinstance(self.accepted_side, Unset):
            accepted_side = self.accepted_side.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if accepted_side is not UNSET:
            field_dict["accepted_side"] = accepted_side

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _accepted_side = d.pop("accepted_side", UNSET)
        accepted_side: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide]
        if isinstance(_accepted_side, Unset):
            accepted_side = UNSET
        else:
            accepted_side = GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide(_accepted_side)

        github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request = cls(
            accepted_side=accepted_side,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_market import (
        GithubComKalshiExchangeInfraSvcApi2ModelMarket,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelEventData")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelEventData:
    """
    Attributes:
        category (Union[Unset, str]): Event category (deprecated, use series-level category instead).
        collateral_return_type (Union[Unset, str]):
        event_ticker (Union[Unset, str]): Unique identifier for this event.
        markets (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelMarket']]): Array of markets associated with
            this event. Only populated when 'with_nested_markets=true' is specified in the request.
        mutually_exclusive (Union[Unset, bool]): If true, only one market in this event can resolve to 'yes'. If false,
            multiple markets can resolve to 'yes'.
        price_level_structure (Union[Unset, str]):
        series_ticker (Union[Unset, str]): Unique identifier for the series this event belongs to.
        strike_date (Union[Unset, Any]):
        strike_period (Union[Unset, str]): The time period this event covers (e.g., 'week', 'month'). Only filled when
            the event uses a period strike (mutually exclusive with strike_date).
        sub_title (Union[Unset, str]): Shortened descriptive title for the event.
        title (Union[Unset, str]): Full title of the event (deprecated, use sub_title instead).
    """

    category: Union[Unset, str] = UNSET
    collateral_return_type: Union[Unset, str] = UNSET
    event_ticker: Union[Unset, str] = UNSET
    markets: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelMarket"]] = UNSET
    mutually_exclusive: Union[Unset, bool] = UNSET
    price_level_structure: Union[Unset, str] = UNSET
    series_ticker: Union[Unset, str] = UNSET
    strike_date: Union[Unset, Any] = UNSET
    strike_period: Union[Unset, str] = UNSET
    sub_title: Union[Unset, str] = UNSET
    title: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        category = self.category

        collateral_return_type = self.collateral_return_type

        event_ticker = self.event_ticker

        markets: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.markets, Unset):
            markets = []
            for markets_item_data in self.markets:
                markets_item = markets_item_data.to_dict()
                markets.append(markets_item)

        mutually_exclusive = self.mutually_exclusive

        price_level_structure = self.price_level_structure

        series_ticker = self.series_ticker

        strike_date = self.strike_date

        strike_period = self.strike_period

        sub_title = self.sub_title

        title = self.title

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if category is not UNSET:
            field_dict["category"] = category
        if collateral_return_type is not UNSET:
            field_dict["collateral_return_type"] = collateral_return_type
        if event_ticker is not UNSET:
            field_dict["event_ticker"] = event_ticker
        if markets is not UNSET:
            field_dict["markets"] = markets
        if mutually_exclusive is not UNSET:
            field_dict["mutually_exclusive"] = mutually_exclusive
        if price_level_structure is not UNSET:
            field_dict["price_level_structure"] = price_level_structure
        if series_ticker is not UNSET:
            field_dict["series_ticker"] = series_ticker
        if strike_date is not UNSET:
            field_dict["strike_date"] = strike_date
        if strike_period is not UNSET:
            field_dict["strike_period"] = strike_period
        if sub_title is not UNSET:
            field_dict["sub_title"] = sub_title
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_market import (
            GithubComKalshiExchangeInfraSvcApi2ModelMarket,
        )

        d = dict(src_dict)
        category = d.pop("category", UNSET)

        collateral_return_type = d.pop("collateral_return_type", UNSET)

        event_ticker = d.pop("event_ticker", UNSET)

        markets = []
        _markets = d.pop("markets", UNSET)
        for markets_item_data in _markets or []:
            markets_item = GithubComKalshiExchangeInfraSvcApi2ModelMarket.from_dict(markets_item_data)

            markets.append(markets_item)

        mutually_exclusive = d.pop("mutually_exclusive", UNSET)

        price_level_structure = d.pop("price_level_structure", UNSET)

        series_ticker = d.pop("series_ticker", UNSET)

        strike_date = d.pop("strike_date", UNSET)

        strike_period = d.pop("strike_period", UNSET)

        sub_title = d.pop("sub_title", UNSET)

        title = d.pop("title", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_event_data = cls(
            category=category,
            collateral_return_type=collateral_return_type,
            event_ticker=event_ticker,
            markets=markets,
            mutually_exclusive=mutually_exclusive,
            price_level_structure=price_level_structure,
            series_ticker=series_ticker,
            strike_date=strike_date,
            strike_period=strike_period,
            sub_title=sub_title,
            title=title,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_event_data.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_event_data

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="OrderQueuePosition")


@_attrs_define
class OrderQueuePosition:
    """
    Attributes:
        market_ticker (Union[Unset, str]):
        order_id (Union[Unset, str]):
        queue_position (Union[Unset, int]):
    """

    market_ticker: Union[Unset, str] = UNSET
    order_id: Union[Unset, str] = UNSET
    queue_position: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        market_ticker = self.market_ticker

        order_id = self.order_id

        queue_position = self.queue_position

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if market_ticker is not UNSET:
            field_dict["market_ticker"] = market_ticker
        if order_id is not UNSET:
            field_dict["order_id"] = order_id
        if queue_position is not UNSET:
            field_dict["queue_position"] = queue_position

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        market_ticker = d.pop("market_ticker", UNSET)

        order_id = d.pop("order_id", UNSET)

        queue_position = d.pop("queue_position", UNSET)

        order_queue_position = cls(
            market_ticker=market_ticker,
            order_id=order_id,
            queue_position=queue_position,
        )

        order_queue_position.additional_properties = d
        return order_queue_position

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelMarket")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelMarket:
    """Contains information about a market

    Attributes:
        ticker (str): Unique identifier for markets
        event_ticker (str): Unique identifier for events
        market_type (str): Type of market (binary, scalar)
        subtitle (str): Shortened title for this market
        yes_sub_title (str): Shortened title for the yes side
        no_sub_title (str): Shortened title for the no side
        open_time (datetime.datetime): Time when trading begins
        close_time (datetime.datetime): Time when trading ends
        expiration_time (datetime.datetime): Time when market expires
        latest_expiration_time (datetime.datetime): Latest possible expiration time
        settlement_timer_seconds (int): Settlement timer in seconds
        status (str): Current market status
        response_price_units (str): Price units for response
        notional_value (int): Notional value of contract
        tick_size (int): Minimum price movement
        yes_bid (int): Highest YES buy offer price
        yes_ask (int): Lowest YES sell offer price
        no_bid (int): Highest NO buy offer price
        no_ask (int): Lowest NO sell offer price
        last_price (int): Last traded price
        previous_yes_bid (int): Previous YES bid price
        previous_yes_ask (int): Previous YES ask price
        previous_price (int): Previous traded price
        volume (int): Trading volume
        volume_24h (int): 24h trading volume
        liquidity (int): Current liquidity
        open_interest (int): Open interest
        result (str): Settlement result
        can_close_early (bool): Whether market can close early
        expiration_value (str): Expiration value
        category (str): Market category
        risk_limit_cents (int): Risk limit in cents
        rules_primary (str): Primary market rules
        rules_secondary (str): Secondary market rules
        title (Union[Unset, str]): Full title describing this market
    """

    ticker: str
    event_ticker: str
    market_type: str
    subtitle: str
    yes_sub_title: str
    no_sub_title: str
    open_time: datetime.datetime
    close_time: datetime.datetime
    expiration_time: datetime.datetime
    latest_expiration_time: datetime.datetime
    settlement_timer_seconds: int
    status: str
    response_price_units: str
    notional_value: int
    tick_size: int
    yes_bid: int
    yes_ask: int
    no_bid: int
    no_ask: int
    last_price: int
    previous_yes_bid: int
    previous_yes_ask: int
    previous_price: int
    volume: int
    volume_24h: int
    liquidity: int
    open_interest: int
    result: str
    can_close_early: bool
    expiration_value: str
    category: str
    risk_limit_cents: int
    rules_primary: str
    rules_secondary: str
    title: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        ticker = self.ticker

        event_ticker = self.event_ticker

        market_type = self.market_type

        subtitle = self.subtitle

        yes_sub_title = self.yes_sub_title

        no_sub_title = self.no_sub_title

        open_time = self.open_time.isoformat()

        close_time = self.close_time.isoformat()

        expiration_time = self.expiration_time.isoformat()

        latest_expiration_time = self.latest_expiration_time.isoformat()

        settlement_timer_seconds = self.settlement_timer_seconds

        status = self.status

        response_price_units = self.response_price_units

        notional_value = self.notional_value

        tick_size = self.tick_size

        yes_bid = self.yes_bid

        yes_ask = self.yes_ask

        no_bid = self.no_bid

        no_ask = self.no_ask

        last_price = self.last_price

        previous_yes_bid = self.previous_yes_bid

        previous_yes_ask = self.previous_yes_ask

        previous_price = self.previous_price

        volume = self.volume

        volume_24h = self.volume_24h

        liquidity = self.liquidity

        open_interest = self.open_interest

        result = self.result

        can_close_early = self.can_close_early

        expiration_value = self.expiration_value

        category = self.category

        risk_limit_cents = self.risk_limit_cents

        rules_primary = self.rules_primary

        rules_secondary = self.rules_secondary

        title = self.title

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ticker": ticker,
                "event_ticker": event_ticker,
                "market_type": market_type,
                "subtitle": subtitle,
                "yes_sub_title": yes_sub_title,
                "no_sub_title": no_sub_title,
                "open_time": open_time,
                "close_time": close_time,
                "expiration_time": expiration_time,
                "latest_expiration_time": latest_expiration_time,
                "settlement_timer_seconds": settlement_timer_seconds,
                "status": status,
                "response_price_units": response_price_units,
                "notional_value": notional_value,
                "tick_size": tick_size,
                "yes_bid": yes_bid,
                "yes_ask": yes_ask,
                "no_bid": no_bid,
                "no_ask": no_ask,
                "last_price": last_price,
                "previous_yes_bid": previous_yes_bid,
                "previous_yes_ask": previous_yes_ask,
                "previous_price": previous_price,
                "volume": volume,
                "volume_24h": volume_24h,
                "liquidity": liquidity,
                "open_interest": open_interest,
                "result": result,
                "can_close_early": can_close_early,
                "expiration_value": expiration_value,
                "category": category,
                "risk_limit_cents": risk_limit_cents,
                "rules_primary": rules_primary,
                "rules_secondary": rules_secondary,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        ticker = d.pop("ticker")

        event_ticker = d.pop("event_ticker")

        market_type = d.pop("market_type")

        subtitle = d.pop("subtitle")

        yes_sub_title = d.pop("yes_sub_title")

        no_sub_title = d.pop("no_sub_title")

        open_time = isoparse(d.pop("open_time"))

        close_time = isoparse(d.pop("close_time"))

        expiration_time = isoparse(d.pop("expiration_time"))

        latest_expiration_time = isoparse(d.pop("latest_expiration_time"))

        settlement_timer_seconds = d.pop("settlement_timer_seconds")

        status = d.pop("status")

        response_price_units = d.pop("response_price_units")

        notional_value = d.pop("notional_value")

        tick_size = d.pop("tick_size")

        yes_bid = d.pop("yes_bid")

        yes_ask = d.pop("yes_ask")

        no_bid = d.pop("no_bid")

        no_ask = d.pop("no_ask")

        last_price = d.pop("last_price")

        previous_yes_bid = d.pop("previous_yes_bid")

        previous_yes_ask = d.pop("previous_yes_ask")

        previous_price = d.pop("previous_price")

        volume = d.pop("volume")

        volume_24h = d.pop("volume_24h")

        liquidity = d.pop("liquidity")

        open_interest = d.pop("open_interest")

        result = d.pop("result")

        can_close_early = d.pop("can_close_early")

        expiration_value = d.pop("expiration_value")

        category = d.pop("category")

        risk_limit_cents = d.pop("risk_limit_cents")

        rules_primary = d.pop("rules_primary")

        rules_secondary = d.pop("rules_secondary")

        title = d.pop("title", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_market = cls(
            ticker=ticker,
            event_ticker=event_ticker,
            market_type=market_type,
            subtitle=subtitle,
            yes_sub_title=yes_sub_title,
            no_sub_title=no_sub_title,
            open_time=open_time,
            close_time=close_time,
            expiration_time=expiration_time,
            latest_expiration_time=latest_expiration_time,
            settlement_timer_seconds=settlement_timer_seconds,
            status=status,
            response_price_units=response_price_units,
            notional_value=notional_value,
            tick_size=tick_size,
            yes_bid=yes_bid,
            yes_ask=yes_ask,
            no_bid=no_bid,
            no_ask=no_ask,
            last_price=last_price,
            previous_yes_bid=previous_yes_bid,
            previous_yes_ask=previous_yes_ask,
            previous_price=previous_price,
            volume=volume,
            volume_24h=volume_24h,
            liquidity=liquidity,
            open_interest=open_interest,
            result=result,
            can_close_early=can_close_early,
            expiration_value=expiration_value,
            category=category,
            risk_limit_cents=risk_limit_cents,
            rules_primary=rules_primary,
            rules_secondary=rules_secondary,
            title=title,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_market.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_market

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_create_market_in_multivariate_event_collection_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
)
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_create_market_in_multivariate_event_collection_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse,
)
from ...types import Response


def _get_kwargs(
    collection_ticker: str,
    *,
    body: GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/multivariate_event_collections/{collection_ticker}",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    if response.status_code == 200:
        response_200 = (
            GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse.from_dict(
                response.json()
            )
        )

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    collection_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    """Create Market In Multivariate Event Collection

      Endpoint for looking up an individual market in a multivariate event collection. This endpoint must
    be hit at least once before trading or looking up a market.

    Args:
        collection_ticker (str): Collection ticker
        body (GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionReq
            uest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]
    """

    kwargs = _get_kwargs(
        collection_ticker=collection_ticker,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    collection_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    """Create Market In Multivariate Event Collection

      Endpoint for looking up an individual market in a multivariate event collection. This endpoint must
    be hit at least once before trading or looking up a market.

    Args:
        collection_ticker (str): Collection ticker
        body (GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionReq
            uest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse
    """

    return sync_detailed(
        collection_ticker=collection_ticker,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    collection_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    """Create Market In Multivariate Event Collection

      Endpoint for looking up an individual market in a multivariate event collection. This endpoint must
    be hit at least once before trading or looking up a market.

    Args:
        collection_ticker (str): Collection ticker
        body (GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionReq
            uest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]
    """

    kwargs = _get_kwargs(
        collection_ticker=collection_ticker,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    collection_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse]:
    """Create Market In Multivariate Event Collection

      Endpoint for looking up an individual market in a multivariate event collection. This endpoint must
    be hit at least once before trading or looking up a market.

    Args:
        collection_ticker (str): Collection ticker
        body (GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionReq
            uest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelCreateMarketInMultivariateEventCollectionResponse
    """

    return (
        await asyncio_detailed(
            collection_ticker=collection_ticker,
            client=client,
            body=body,
        )
    ).parsed



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_accept_quote_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest,
)
from ...types import Response


def _get_kwargs(
    quote_id: str,
    *,
    body: GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/communications/quotes/{quote_id}/accept",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
    if response.status_code == 204:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    quote_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest,
) -> Response[Any]:
    """Accept Quote

      Endpoint for accepting a quote. This will require the quoter to confirm

    Args:
        quote_id (str): Quote ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        quote_id=quote_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    quote_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest,
) -> Response[Any]:
    """Accept Quote

      Endpoint for accepting a quote. This will require the quoter to confirm

    Args:
        quote_id (str): Quote ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        quote_id=quote_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_event_data import (
        GithubComKalshiExchangeInfraSvcApi2ModelEventData,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetEventsResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetEventsResponse:
    """
    Attributes:
        cursor (Union[Unset, str]): Pagination cursor for the next page. Empty if there are no more results.
        events (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelEventData']]): Array of events matching the
            query criteria.
    """

    cursor: Union[Unset, str] = UNSET
    events: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelEventData"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cursor = self.cursor

        events: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.events, Unset):
            events = []
            for events_item_data in self.events:
                events_item = events_item_data.to_dict()
                events.append(events_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if events is not UNSET:
            field_dict["events"] = events

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_event_data import (
            GithubComKalshiExchangeInfraSvcApi2ModelEventData,
        )

        d = dict(src_dict)
        cursor = d.pop("cursor", UNSET)

        events = []
        _events = d.pop("events", UNSET)
        for events_item_data in _events or []:
            events_item = GithubComKalshiExchangeInfraSvcApi2ModelEventData.from_dict(events_item_data)

            events.append(events_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_events_response = cls(
            cursor=cursor,
            events=events,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_events_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_events_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_event_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    event_ticker: str,
    *,
    with_nested_markets: Union[Unset, bool] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["with_nested_markets"] = with_nested_markets

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/events/{event_ticker}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    event_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    with_nested_markets: Union[Unset, bool] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    """Get Event

      Endpoint for getting data about an event by its ticker.  An event represents a real-world
    occurrence that can be traded on, such as an election, sports game, or economic indicator release.
    Events contain one or more markets where users can place trades on different outcomes.

    Args:
        event_ticker (str): Event ticker
        with_nested_markets (Union[Unset, bool]): If true, markets are included within the event
            object. If false (default), markets are returned as a separate top-level field in the
            response.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]
    """

    kwargs = _get_kwargs(
        event_ticker=event_ticker,
        with_nested_markets=with_nested_markets,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    event_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    with_nested_markets: Union[Unset, bool] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    """Get Event

      Endpoint for getting data about an event by its ticker.  An event represents a real-world
    occurrence that can be traded on, such as an election, sports game, or economic indicator release.
    Events contain one or more markets where users can place trades on different outcomes.

    Args:
        event_ticker (str): Event ticker
        with_nested_markets (Union[Unset, bool]): If true, markets are included within the event
            object. If false (default), markets are returned as a separate top-level field in the
            response.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse
    """

    return sync_detailed(
        event_ticker=event_ticker,
        client=client,
        with_nested_markets=with_nested_markets,
    ).parsed


async def asyncio_detailed(
    event_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    with_nested_markets: Union[Unset, bool] = UNSET,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    """Get Event

      Endpoint for getting data about an event by its ticker.  An event represents a real-world
    occurrence that can be traded on, such as an election, sports game, or economic indicator release.
    Events contain one or more markets where users can place trades on different outcomes.

    Args:
        event_ticker (str): Event ticker
        with_nested_markets (Union[Unset, bool]): If true, markets are included within the event
            object. If false (default), markets are returned as a separate top-level field in the
            response.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]
    """

    kwargs = _get_kwargs(
        event_ticker=event_ticker,
        with_nested_markets=with_nested_markets,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    event_ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    with_nested_markets: Union[Unset, bool] = UNSET,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse]:
    """Get Event

      Endpoint for getting data about an event by its ticker.  An event represents a real-world
    occurrence that can be traded on, such as an election, sports game, or economic indicator release.
    Events contain one or more markets where users can place trades on different outcomes.

    Args:
        event_ticker (str): Event ticker
        with_nested_markets (Union[Unset, bool]): If true, markets are included within the event
            object. If false (default), markets are returned as a separate top-level field in the
            response.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse
    """

    return (
        await asyncio_detailed(
            event_ticker=event_ticker,
            client=client,
            with_nested_markets=with_nested_markets,
        )
    ).parsed



from enum import Enum


class GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType(str, Enum):
    LIMIT = "limit"
    MARKET = "market"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_public_trade import (
        GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelPublicTradesGetResponse:
    """
    Attributes:
        cursor (Union[Unset, str]): The Cursor represents a pointer to the next page of records in the pagination. Use
            the value returned here in the cursor query parameter for this end-point to get the next page containing limit
            records. An empty value of this field indicates there is no next page.
        trades (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade']]):
    """

    cursor: Union[Unset, str] = UNSET
    trades: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cursor = self.cursor

        trades: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.trades, Unset):
            trades = []
            for (
                componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item_data
            ) in self.trades:
                componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item = componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item_data.to_dict()
                trades.append(componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if trades is not UNSET:
            field_dict["trades"] = trades

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_public_trade import (
            GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade,
        )

        d = dict(src_dict)
        cursor = d.pop("cursor", UNSET)

        trades = []
        _trades = d.pop("trades", UNSET)
        for componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item_data in (
            _trades or []
        ):
            componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item = (
                GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade.from_dict(
                    componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item_data
                )
            )

            trades.append(componentsschemasgithub_com_kalshi_exchange_infra_svc_api_2_model_public_trade_list_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_public_trades_get_response = cls(
            cursor=cursor,
            trades=trades,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_public_trades_get_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_public_trades_get_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_request import (
    GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
)
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_decrease_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse,
)
from ...types import Response


def _get_kwargs(
    order_id: str,
    *,
    body: GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/portfolio/orders/{order_id}/decrease",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    """Decrease Order

      Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit
    available on order quantity. Cancelling an order is equivalent to decreasing an order amount to
    zero.

    Args:
        order_id (str): Order ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]
    """

    kwargs = _get_kwargs(
        order_id=order_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    """Decrease Order

      Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit
    available on order quantity. Cancelling an order is equivalent to decreasing an order amount to
    zero.

    Args:
        order_id (str): Order ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse
    """

    return sync_detailed(
        order_id=order_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    """Decrease Order

      Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit
    available on order quantity. Cancelling an order is equivalent to decreasing an order amount to
    zero.

    Args:
        order_id (str): Order ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]
    """

    kwargs = _get_kwargs(
        order_id=order_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse]:
    """Decrease Order

      Endpoint for decreasing the number of contracts in an existing order. This is the only kind of edit
    available on order quantity. Cancelling an order is equivalent to decreasing an order amount to
    zero.

    Args:
        order_id (str): Order ID
        body (GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelDecreaseOrderResponse
    """

    return (
        await asyncio_detailed(
            order_id=order_id,
            client=client,
            body=body,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelPriceDistribution")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelPriceDistribution:
    """
    Attributes:
        close (Union[Unset, int]):
        close_dollars (Union[Unset, list[int]]):
        high (Union[Unset, int]):
        high_dollars (Union[Unset, list[int]]):
        low (Union[Unset, int]):
        low_dollars (Union[Unset, list[int]]):
        mean (Union[Unset, int]):
        mean_dollars (Union[Unset, list[int]]):
        open_ (Union[Unset, int]):
        open_dollars (Union[Unset, list[int]]):
        previous (Union[Unset, int]):
        previous_dollars (Union[Unset, list[int]]):
    """

    close: Union[Unset, int] = UNSET
    close_dollars: Union[Unset, list[int]] = UNSET
    high: Union[Unset, int] = UNSET
    high_dollars: Union[Unset, list[int]] = UNSET
    low: Union[Unset, int] = UNSET
    low_dollars: Union[Unset, list[int]] = UNSET
    mean: Union[Unset, int] = UNSET
    mean_dollars: Union[Unset, list[int]] = UNSET
    open_: Union[Unset, int] = UNSET
    open_dollars: Union[Unset, list[int]] = UNSET
    previous: Union[Unset, int] = UNSET
    previous_dollars: Union[Unset, list[int]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        close = self.close

        close_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.close_dollars, Unset):
            close_dollars = self.close_dollars

        high = self.high

        high_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.high_dollars, Unset):
            high_dollars = self.high_dollars

        low = self.low

        low_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.low_dollars, Unset):
            low_dollars = self.low_dollars

        mean = self.mean

        mean_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.mean_dollars, Unset):
            mean_dollars = self.mean_dollars

        open_ = self.open_

        open_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.open_dollars, Unset):
            open_dollars = self.open_dollars

        previous = self.previous

        previous_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.previous_dollars, Unset):
            previous_dollars = self.previous_dollars

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if close is not UNSET:
            field_dict["close"] = close
        if close_dollars is not UNSET:
            field_dict["close_dollars"] = close_dollars
        if high is not UNSET:
            field_dict["high"] = high
        if high_dollars is not UNSET:
            field_dict["high_dollars"] = high_dollars
        if low is not UNSET:
            field_dict["low"] = low
        if low_dollars is not UNSET:
            field_dict["low_dollars"] = low_dollars
        if mean is not UNSET:
            field_dict["mean"] = mean
        if mean_dollars is not UNSET:
            field_dict["mean_dollars"] = mean_dollars
        if open_ is not UNSET:
            field_dict["open"] = open_
        if open_dollars is not UNSET:
            field_dict["open_dollars"] = open_dollars
        if previous is not UNSET:
            field_dict["previous"] = previous
        if previous_dollars is not UNSET:
            field_dict["previous_dollars"] = previous_dollars

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        close = d.pop("close", UNSET)

        close_dollars = cast(list[int], d.pop("close_dollars", UNSET))

        high = d.pop("high", UNSET)

        high_dollars = cast(list[int], d.pop("high_dollars", UNSET))

        low = d.pop("low", UNSET)

        low_dollars = cast(list[int], d.pop("low_dollars", UNSET))

        mean = d.pop("mean", UNSET)

        mean_dollars = cast(list[int], d.pop("mean_dollars", UNSET))

        open_ = d.pop("open", UNSET)

        open_dollars = cast(list[int], d.pop("open_dollars", UNSET))

        previous = d.pop("previous", UNSET)

        previous_dollars = cast(list[int], d.pop("previous_dollars", UNSET))

        github_com_kalshi_exchange_infra_svc_api_2_model_price_distribution = cls(
            close=close,
            close_dollars=close_dollars,
            high=high,
            high_dollars=high_dollars,
            low=low,
            low_dollars=low_dollars,
            mean=mean,
            mean_dollars=mean_dollars,
            open_=open_,
            open_dollars=open_dollars,
            previous=previous,
            previous_dollars=previous_dollars,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_price_distribution.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_price_distribution

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection import (
        GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionsResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionsResponse:
    """
    Attributes:
        cursor (Union[Unset, str]): The Cursor represents a pointer to the next page of records in the pagination. Use
            the value returned here in the cursor query parameter for this end-point to get the next page containing limit
            records. An empty value of this field indicates there is no next page.
        multivariate_contracts (Union[Unset,
            list['GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection']]): List of multivariate event
            collections.
    """

    cursor: Union[Unset, str] = UNSET
    multivariate_contracts: Union[
        Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection"]
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cursor = self.cursor

        multivariate_contracts: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.multivariate_contracts, Unset):
            multivariate_contracts = []
            for multivariate_contracts_item_data in self.multivariate_contracts:
                multivariate_contracts_item = multivariate_contracts_item_data.to_dict()
                multivariate_contracts.append(multivariate_contracts_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if multivariate_contracts is not UNSET:
            field_dict["multivariate_contracts"] = multivariate_contracts

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection import (
            GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection,
        )

        d = dict(src_dict)
        cursor = d.pop("cursor", UNSET)

        multivariate_contracts = []
        _multivariate_contracts = d.pop("multivariate_contracts", UNSET)
        for multivariate_contracts_item_data in _multivariate_contracts or []:
            multivariate_contracts_item = GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection.from_dict(
                multivariate_contracts_item_data
            )

            multivariate_contracts.append(multivariate_contracts_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collections_response = cls(
            cursor=cursor,
            multivariate_contracts=multivariate_contracts,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collections_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collections_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_user_data_timestamp_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse,
)
from ...types import Response


def _get_kwargs() -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/exchange/user_data_timestamp",
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    """Get User Data Timestamp

      There is typically a short delay before exchange events are reflected in the API endpoints.
    Whenever possible, combine API responses to PUT/POST/DELETE requests with websocket data to obtain
    the most accurate view of the exchange state. This endpoint provides an approximate indication of
    when the data from the following endpoints was last validated: GetBalance, GetOrder(s), GetFills,
    GetPositions

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    """Get User Data Timestamp

      There is typically a short delay before exchange events are reflected in the API endpoints.
    Whenever possible, combine API responses to PUT/POST/DELETE requests with websocket data to obtain
    the most accurate view of the exchange state. This endpoint provides an approximate indication of
    when the data from the following endpoints was last validated: GetBalance, GetOrder(s), GetFills,
    GetPositions

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    """Get User Data Timestamp

      There is typically a short delay before exchange events are reflected in the API endpoints.
    Whenever possible, combine API responses to PUT/POST/DELETE requests with websocket data to obtain
    the most accurate view of the exchange state. This endpoint provides an approximate indication of
    when the data from the following endpoints was last validated: GetBalance, GetOrder(s), GetFills,
    GetPositions

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse]:
    """Get User Data Timestamp

      There is typically a short delay before exchange events are reflected in the API endpoints.
    Whenever possible, combine API responses to PUT/POST/DELETE requests with websocket data to obtain
    the most accurate view of the exchange state. This endpoint provides an approximate indication of
    when the data from the following endpoints was last validated: GetBalance, GetOrder(s), GetFills,
    GetPositions

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetUserDataTimestampResponse
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelPublicTrade:
    """
    Attributes:
        count (Union[Unset, int]): Number of contracts bought or sold in this trade.
        created_time (Union[Unset, Any]):
        no_price (Union[Unset, int]):
        taker_side (Union[Unset, str]):
        ticker (Union[Unset, str]): Unique identifier for the market.
        trade_id (Union[Unset, str]):
        yes_price (Union[Unset, int]):
    """

    count: Union[Unset, int] = UNSET
    created_time: Union[Unset, Any] = UNSET
    no_price: Union[Unset, int] = UNSET
    taker_side: Union[Unset, str] = UNSET
    ticker: Union[Unset, str] = UNSET
    trade_id: Union[Unset, str] = UNSET
    yes_price: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        count = self.count

        created_time = self.created_time

        no_price = self.no_price

        taker_side = self.taker_side

        ticker = self.ticker

        trade_id = self.trade_id

        yes_price = self.yes_price

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if count is not UNSET:
            field_dict["count"] = count
        if created_time is not UNSET:
            field_dict["created_time"] = created_time
        if no_price is not UNSET:
            field_dict["no_price"] = no_price
        if taker_side is not UNSET:
            field_dict["taker_side"] = taker_side
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if trade_id is not UNSET:
            field_dict["trade_id"] = trade_id
        if yes_price is not UNSET:
            field_dict["yes_price"] = yes_price

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        count = d.pop("count", UNSET)

        created_time = d.pop("created_time", UNSET)

        no_price = d.pop("no_price", UNSET)

        taker_side = d.pop("taker_side", UNSET)

        ticker = d.pop("ticker", UNSET)

        trade_id = d.pop("trade_id", UNSET)

        yes_price = d.pop("yes_price", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_public_trade = cls(
            count=count,
            created_time=created_time,
            no_price=no_price,
            taker_side=taker_side,
            ticker=ticker,
            trade_id=trade_id,
            yes_price=yes_price,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_public_trade.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_public_trade

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_event_data import (
        GithubComKalshiExchangeInfraSvcApi2ModelEventData,
    )
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_market import (
        GithubComKalshiExchangeInfraSvcApi2ModelMarket,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetEventResponse:
    """
    Attributes:
        event (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelEventData]):
        markets (Union[Unset, list['GithubComKalshiExchangeInfraSvcApi2ModelMarket']]):
    """

    event: Union[Unset, "GithubComKalshiExchangeInfraSvcApi2ModelEventData"] = UNSET
    markets: Union[Unset, list["GithubComKalshiExchangeInfraSvcApi2ModelMarket"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        event: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.event, Unset):
            event = self.event.to_dict()

        markets: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.markets, Unset):
            markets = []
            for markets_item_data in self.markets:
                markets_item = markets_item_data.to_dict()
                markets.append(markets_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if event is not UNSET:
            field_dict["event"] = event
        if markets is not UNSET:
            field_dict["markets"] = markets

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_event_data import (
            GithubComKalshiExchangeInfraSvcApi2ModelEventData,
        )
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_market import (
            GithubComKalshiExchangeInfraSvcApi2ModelMarket,
        )

        d = dict(src_dict)
        _event = d.pop("event", UNSET)
        event: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelEventData]
        if isinstance(_event, Unset):
            event = UNSET
        else:
            event = GithubComKalshiExchangeInfraSvcApi2ModelEventData.from_dict(_event)

        markets = []
        _markets = d.pop("markets", UNSET)
        for markets_item_data in _markets or []:
            markets_item = GithubComKalshiExchangeInfraSvcApi2ModelMarket.from_dict(markets_item_data)

            markets.append(markets_item)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_event_response = cls(
            event=event,
            markets=markets,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_event_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_event_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection import (
        GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetMultivariateEventCollectionResponse:
    """
    Attributes:
        multivariate_contract (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection]):
    """

    multivariate_contract: Union[Unset, "GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        multivariate_contract: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.multivariate_contract, Unset):
            multivariate_contract = self.multivariate_contract.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if multivariate_contract is not UNSET:
            field_dict["multivariate_contract"] = multivariate_contract

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection import (
            GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection,
        )

        d = dict(src_dict)
        _multivariate_contract = d.pop("multivariate_contract", UNSET)
        multivariate_contract: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection]
        if isinstance(_multivariate_contract, Unset):
            multivariate_contract = UNSET
        else:
            multivariate_contract = GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection.from_dict(
                _multivariate_contract
            )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_response = cls(
            multivariate_contract=multivariate_contract,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_multivariate_event_collection_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_daily_schedule import (
        GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule,
    )
    from ..models.weekly_schedule_monday_item import WeeklyScheduleMondayItem


T = TypeVar("T", bound="WeeklySchedule")


@_attrs_define
class WeeklySchedule:
    """
    Attributes:
        end_time (Union[Unset, datetime.datetime]): End date and time for when this weekly schedule is no longer
            effective.
        friday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Friday. May contain multiple sessions.
        monday (Union[Unset, list['WeeklyScheduleMondayItem']]): Trading hours for Monday. May contain multiple
            sessions.
        saturday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Saturday. May contain multiple sessions.
        start_time (Union[Unset, datetime.datetime]): Start date and time for when this weekly schedule is effective.
        sunday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Sunday. May contain multiple sessions.
        thursday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Thursday. May contain multiple sessions.
        tuesday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Tuesday. May contain multiple sessions.
        wednesday (Union[Unset, list['GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule']]): Trading hours
            for Wednesday. May contain multiple sessions.
    """

    end_time: Union[Unset, datetime.datetime] = UNSET
    friday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    monday: Union[Unset, list["WeeklyScheduleMondayItem"]] = UNSET
    saturday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    start_time: Union[Unset, datetime.datetime] = UNSET
    sunday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    thursday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    tuesday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    wednesday: Union[Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        end_time: Union[Unset, str] = UNSET
        if not isinstance(self.end_time, Unset):
            end_time = self.end_time.isoformat()

        friday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.friday, Unset):
            friday = []
            for friday_item_data in self.friday:
                friday_item = friday_item_data.to_dict()
                friday.append(friday_item)

        monday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.monday, Unset):
            monday = []
            for monday_item_data in self.monday:
                monday_item = monday_item_data.to_dict()
                monday.append(monday_item)

        saturday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.saturday, Unset):
            saturday = []
            for saturday_item_data in self.saturday:
                saturday_item = saturday_item_data.to_dict()
                saturday.append(saturday_item)

        start_time: Union[Unset, str] = UNSET
        if not isinstance(self.start_time, Unset):
            start_time = self.start_time.isoformat()

        sunday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.sunday, Unset):
            sunday = []
            for sunday_item_data in self.sunday:
                sunday_item = sunday_item_data.to_dict()
                sunday.append(sunday_item)

        thursday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.thursday, Unset):
            thursday = []
            for thursday_item_data in self.thursday:
                thursday_item = thursday_item_data.to_dict()
                thursday.append(thursday_item)

        tuesday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.tuesday, Unset):
            tuesday = []
            for tuesday_item_data in self.tuesday:
                tuesday_item = tuesday_item_data.to_dict()
                tuesday.append(tuesday_item)

        wednesday: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.wednesday, Unset):
            wednesday = []
            for wednesday_item_data in self.wednesday:
                wednesday_item = wednesday_item_data.to_dict()
                wednesday.append(wednesday_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if end_time is not UNSET:
            field_dict["end_time"] = end_time
        if friday is not UNSET:
            field_dict["friday"] = friday
        if monday is not UNSET:
            field_dict["monday"] = monday
        if saturday is not UNSET:
            field_dict["saturday"] = saturday
        if start_time is not UNSET:
            field_dict["start_time"] = start_time
        if sunday is not UNSET:
            field_dict["sunday"] = sunday
        if thursday is not UNSET:
            field_dict["thursday"] = thursday
        if tuesday is not UNSET:
            field_dict["tuesday"] = tuesday
        if wednesday is not UNSET:
            field_dict["wednesday"] = wednesday

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_daily_schedule import (
            GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule,
        )
        from ..models.weekly_schedule_monday_item import WeeklyScheduleMondayItem

        d = dict(src_dict)
        _end_time = d.pop("end_time", UNSET)
        end_time: Union[Unset, datetime.datetime]
        if isinstance(_end_time, Unset):
            end_time = UNSET
        else:
            end_time = isoparse(_end_time)

        friday = []
        _friday = d.pop("friday", UNSET)
        for friday_item_data in _friday or []:
            friday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(friday_item_data)

            friday.append(friday_item)

        monday = []
        _monday = d.pop("monday", UNSET)
        for monday_item_data in _monday or []:
            monday_item = WeeklyScheduleMondayItem.from_dict(monday_item_data)

            monday.append(monday_item)

        saturday = []
        _saturday = d.pop("saturday", UNSET)
        for saturday_item_data in _saturday or []:
            saturday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(
                saturday_item_data
            )

            saturday.append(saturday_item)

        _start_time = d.pop("start_time", UNSET)
        start_time: Union[Unset, datetime.datetime]
        if isinstance(_start_time, Unset):
            start_time = UNSET
        else:
            start_time = isoparse(_start_time)

        sunday = []
        _sunday = d.pop("sunday", UNSET)
        for sunday_item_data in _sunday or []:
            sunday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(sunday_item_data)

            sunday.append(sunday_item)

        thursday = []
        _thursday = d.pop("thursday", UNSET)
        for thursday_item_data in _thursday or []:
            thursday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(
                thursday_item_data
            )

            thursday.append(thursday_item)

        tuesday = []
        _tuesday = d.pop("tuesday", UNSET)
        for tuesday_item_data in _tuesday or []:
            tuesday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(tuesday_item_data)

            tuesday.append(tuesday_item)

        wednesday = []
        _wednesday = d.pop("wednesday", UNSET)
        for wednesday_item_data in _wednesday or []:
            wednesday_item = GithubComKalshiExchangeInfraCommonExchangeMetadataDailySchedule.from_dict(
                wednesday_item_data
            )

            wednesday.append(wednesday_item)

        weekly_schedule = cls(
            end_time=end_time,
            friday=friday,
            monday=monday,
            saturday=saturday,
            start_time=start_time,
            sunday=sunday,
            thursday=thursday,
            tuesday=tuesday,
            wednesday=wednesday,
        )

        weekly_schedule.additional_properties = d
        return weekly_schedule

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.ticker_pair_side import TickerPairSide
from ..types import UNSET, Unset

T = TypeVar("T", bound="TickerPair")


@_attrs_define
class TickerPair:
    """
    Attributes:
        event_ticker (Union[Unset, str]): Event ticker identifier.
        market_ticker (Union[Unset, str]): Market ticker identifier.
        side (Union[Unset, TickerPairSide]): Side of the market (yes or no).
    """

    event_ticker: Union[Unset, str] = UNSET
    market_ticker: Union[Unset, str] = UNSET
    side: Union[Unset, TickerPairSide] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        event_ticker = self.event_ticker

        market_ticker = self.market_ticker

        side: Union[Unset, str] = UNSET
        if not isinstance(self.side, Unset):
            side = self.side.value

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if event_ticker is not UNSET:
            field_dict["event_ticker"] = event_ticker
        if market_ticker is not UNSET:
            field_dict["market_ticker"] = market_ticker
        if side is not UNSET:
            field_dict["side"] = side

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        event_ticker = d.pop("event_ticker", UNSET)

        market_ticker = d.pop("market_ticker", UNSET)

        _side = d.pop("side", UNSET)
        side: Union[Unset, TickerPairSide]
        if isinstance(_side, Unset):
            side = UNSET
        else:
            side = TickerPairSide(_side)

        ticker_pair = cls(
            event_ticker=event_ticker,
            market_ticker=market_ticker,
            side=side,
        )

        ticker_pair.additional_properties = d
        return ticker_pair

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupResponse")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetOrderGroupResponse:
    """
    Attributes:
        is_auto_cancel_enabled (Union[Unset, bool]): Whether auto-cancel is enabled for this order group.
        orders (Union[Unset, list[str]]): List of order IDs that belong to this order group.
    """

    is_auto_cancel_enabled: Union[Unset, bool] = UNSET
    orders: Union[Unset, list[str]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        is_auto_cancel_enabled = self.is_auto_cancel_enabled

        orders: Union[Unset, list[str]] = UNSET
        if not isinstance(self.orders, Unset):
            orders = self.orders

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if is_auto_cancel_enabled is not UNSET:
            field_dict["is_auto_cancel_enabled"] = is_auto_cancel_enabled
        if orders is not UNSET:
            field_dict["orders"] = orders

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        is_auto_cancel_enabled = d.pop("is_auto_cancel_enabled", UNSET)

        orders = cast(list[str], d.pop("orders", UNSET))

        github_com_kalshi_exchange_infra_svc_api_2_model_get_order_group_response = cls(
            is_auto_cancel_enabled=is_auto_cancel_enabled,
            orders=orders,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_order_group_response.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_order_group_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_cancel_order_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse,
)
from ...types import Response


def _get_kwargs(
    order_id: str,
) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/portfolio/orders/{order_id}",
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    """Cancel Order

      Endpoint for canceling orders. The value for the orderId should match the id field of the order you
    want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success.
    But we can't completely delete the order, as it may be partially filled already. Instead, the
    DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting
    contracts on it. The zeroed order is returned on the response payload as a form of validation for
    the client.

    Args:
        order_id (str): Order ID

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]
    """

    kwargs = _get_kwargs(
        order_id=order_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    """Cancel Order

      Endpoint for canceling orders. The value for the orderId should match the id field of the order you
    want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success.
    But we can't completely delete the order, as it may be partially filled already. Instead, the
    DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting
    contracts on it. The zeroed order is returned on the response payload as a form of validation for
    the client.

    Args:
        order_id (str): Order ID

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse
    """

    return sync_detailed(
        order_id=order_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    """Cancel Order

      Endpoint for canceling orders. The value for the orderId should match the id field of the order you
    want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success.
    But we can't completely delete the order, as it may be partially filled already. Instead, the
    DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting
    contracts on it. The zeroed order is returned on the response payload as a form of validation for
    the client.

    Args:
        order_id (str): Order ID

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]
    """

    kwargs = _get_kwargs(
        order_id=order_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    order_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse]:
    """Cancel Order

      Endpoint for canceling orders. The value for the orderId should match the id field of the order you
    want to decrease. Commonly, DELETE-type endpoints return 204 status with no body content on success.
    But we can't completely delete the order, as it may be partially filled already. Instead, the
    DeleteOrder endpoint reduce the order completely, essentially zeroing the remaining resting
    contracts on it. The zeroed order is returned on the response payload as a form of validation for
    the client.

    Args:
        order_id (str): Order ID

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelCancelOrderResponse
    """

    return (
        await asyncio_detailed(
            order_id=order_id,
            client=client,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelMultivariateEventCollection:
    """
    Attributes:
        associated_event_tickers (Union[Unset, list[str]]): A list of events associated with the collection. Markets in
            these events can be passed as inputs to the Lookup and Create endpoints.
        close_date (Union[Unset, datetime.datetime]): The close date of the collection. After this time, the collection
            cannot be interacted with.
        collection_ticker (Union[Unset, str]): Unique identifier for the collection.
        description (Union[Unset, str]): Short description of the collection.
        functional_description (Union[Unset, str]): A functional description of the collection describing how inputs
            affect the output.
        is_all_yes (Union[Unset, bool]): Whether the collection requires that only the market side of 'yes' may be used.
        is_ordered (Union[Unset, bool]): Whether the collection is ordered. If true, the order of markets passed into
            Lookup/Create affects the output. If false, the order does not matter.
        is_single_market_per_event (Union[Unset, bool]): Whether the collection accepts multiple markets from the same
            event passed into Lookup/Create.
        open_date (Union[Unset, datetime.datetime]): The open date of the collection. Before this time, the collection
            cannot be interacted with.
        series_ticker (Union[Unset, str]): Series associated with the collection. Events produced in the collection will
            be associated with this series.
        size_max (Union[Unset, int]): The maximum number of markets that must be passed into Lookup/Create (inclusive).
        size_min (Union[Unset, int]): The minimum number of markets that must be passed into Lookup/Create (inclusive).
        title (Union[Unset, str]): Title of the collection.
    """

    associated_event_tickers: Union[Unset, list[str]] = UNSET
    close_date: Union[Unset, datetime.datetime] = UNSET
    collection_ticker: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    functional_description: Union[Unset, str] = UNSET
    is_all_yes: Union[Unset, bool] = UNSET
    is_ordered: Union[Unset, bool] = UNSET
    is_single_market_per_event: Union[Unset, bool] = UNSET
    open_date: Union[Unset, datetime.datetime] = UNSET
    series_ticker: Union[Unset, str] = UNSET
    size_max: Union[Unset, int] = UNSET
    size_min: Union[Unset, int] = UNSET
    title: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        associated_event_tickers: Union[Unset, list[str]] = UNSET
        if not isinstance(self.associated_event_tickers, Unset):
            associated_event_tickers = self.associated_event_tickers

        close_date: Union[Unset, str] = UNSET
        if not isinstance(self.close_date, Unset):
            close_date = self.close_date.isoformat()

        collection_ticker = self.collection_ticker

        description = self.description

        functional_description = self.functional_description

        is_all_yes = self.is_all_yes

        is_ordered = self.is_ordered

        is_single_market_per_event = self.is_single_market_per_event

        open_date: Union[Unset, str] = UNSET
        if not isinstance(self.open_date, Unset):
            open_date = self.open_date.isoformat()

        series_ticker = self.series_ticker

        size_max = self.size_max

        size_min = self.size_min

        title = self.title

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if associated_event_tickers is not UNSET:
            field_dict["associated_event_tickers"] = associated_event_tickers
        if close_date is not UNSET:
            field_dict["close_date"] = close_date
        if collection_ticker is not UNSET:
            field_dict["collection_ticker"] = collection_ticker
        if description is not UNSET:
            field_dict["description"] = description
        if functional_description is not UNSET:
            field_dict["functional_description"] = functional_description
        if is_all_yes is not UNSET:
            field_dict["is_all_yes"] = is_all_yes
        if is_ordered is not UNSET:
            field_dict["is_ordered"] = is_ordered
        if is_single_market_per_event is not UNSET:
            field_dict["is_single_market_per_event"] = is_single_market_per_event
        if open_date is not UNSET:
            field_dict["open_date"] = open_date
        if series_ticker is not UNSET:
            field_dict["series_ticker"] = series_ticker
        if size_max is not UNSET:
            field_dict["size_max"] = size_max
        if size_min is not UNSET:
            field_dict["size_min"] = size_min
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        associated_event_tickers = cast(list[str], d.pop("associated_event_tickers", UNSET))

        _close_date = d.pop("close_date", UNSET)
        close_date: Union[Unset, datetime.datetime]
        if isinstance(_close_date, Unset):
            close_date = UNSET
        else:
            close_date = isoparse(_close_date)

        collection_ticker = d.pop("collection_ticker", UNSET)

        description = d.pop("description", UNSET)

        functional_description = d.pop("functional_description", UNSET)

        is_all_yes = d.pop("is_all_yes", UNSET)

        is_ordered = d.pop("is_ordered", UNSET)

        is_single_market_per_event = d.pop("is_single_market_per_event", UNSET)

        _open_date = d.pop("open_date", UNSET)
        open_date: Union[Unset, datetime.datetime]
        if isinstance(_open_date, Unset):
            open_date = UNSET
        else:
            open_date = isoparse(_open_date)

        series_ticker = d.pop("series_ticker", UNSET)

        size_max = d.pop("size_max", UNSET)

        size_min = d.pop("size_min", UNSET)

        title = d.pop("title", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection = cls(
            associated_event_tickers=associated_event_tickers,
            close_date=close_date,
            collection_ticker=collection_ticker,
            description=description,
            functional_description=functional_description,
            is_all_yes=is_all_yes,
            is_ordered=is_ordered,
            is_single_market_per_event=is_single_market_per_event,
            open_date=open_date,
            series_ticker=series_ticker,
            size_max=size_max,
            size_min=size_min,
            title=title,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_multivariate_event_collection

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_action import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction,
)
from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_side import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide,
)
from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_time_in_force import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce,
)
from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request_type import (
    GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequest")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequest:
    """
    Attributes:
        action (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction]): Specifies if this is a
            buy or sell order.
        buy_max_cost (Union[Unset, int]):
        client_order_id (Union[Unset, str]):
        count (Union[Unset, int]): Number of contracts to be bought or sold.
        expiration_ts (Union[Unset, int]): Expiration time of the order, in unix seconds. If not supplied, the order
            won't expire until explicitly cancelled (GTC). If the time is in the past, the order will attempt to fill and
            cancel any remainder (IOC). If the time is in the future, the unfilled quantity will expire at the specified
            time.
        no_price (Union[Unset, int]):
        no_price_dollars (Union[Unset, list[int]]):
        order_group_id (Union[Unset, str]):
        post_only (Union[Unset, bool]): If this flag is set to true, an order will be rejected if it crosses the spread
            and executes.
        self_trade_prevention_type (Union[Unset, str]):
        sell_position_capped (Union[Unset, bool]): SellPositionCapped prevents sell orders from exceeding your current
            position. This option can only be used with Immediate-or-Cancel (IoC) orders.
        sell_position_floor (Union[Unset, int]): SellPositionFloor will not let you flip position for a market order if
            set to 0. Deprecated: Use sell_position_capped instead.
        side (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide]): Specifies if this is a
            'yes' or 'no' order.
        ticker (Union[Unset, str]): The ticker of the market the order will be placed in.
        time_in_force (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce]): Currently
            only 'fill_or_kill' and 'immediate_or_cancel' are supported. Other time in forces are controlled through
            expiration_ts.
        type_ (Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType]): Specifies if this is a
            'market' or a 'limit' order. Note that either the Yes Price or the No Price must be provided for limit orders.
        yes_price (Union[Unset, int]):
        yes_price_dollars (Union[Unset, list[int]]):
    """

    action: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction] = UNSET
    buy_max_cost: Union[Unset, int] = UNSET
    client_order_id: Union[Unset, str] = UNSET
    count: Union[Unset, int] = UNSET
    expiration_ts: Union[Unset, int] = UNSET
    no_price: Union[Unset, int] = UNSET
    no_price_dollars: Union[Unset, list[int]] = UNSET
    order_group_id: Union[Unset, str] = UNSET
    post_only: Union[Unset, bool] = UNSET
    self_trade_prevention_type: Union[Unset, str] = UNSET
    sell_position_capped: Union[Unset, bool] = UNSET
    sell_position_floor: Union[Unset, int] = UNSET
    side: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide] = UNSET
    ticker: Union[Unset, str] = UNSET
    time_in_force: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce] = UNSET
    type_: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType] = UNSET
    yes_price: Union[Unset, int] = UNSET
    yes_price_dollars: Union[Unset, list[int]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        action: Union[Unset, str] = UNSET
        if not isinstance(self.action, Unset):
            action = self.action.value

        buy_max_cost = self.buy_max_cost

        client_order_id = self.client_order_id

        count = self.count

        expiration_ts = self.expiration_ts

        no_price = self.no_price

        no_price_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.no_price_dollars, Unset):
            no_price_dollars = self.no_price_dollars

        order_group_id = self.order_group_id

        post_only = self.post_only

        self_trade_prevention_type = self.self_trade_prevention_type

        sell_position_capped = self.sell_position_capped

        sell_position_floor = self.sell_position_floor

        side: Union[Unset, str] = UNSET
        if not isinstance(self.side, Unset):
            side = self.side.value

        ticker = self.ticker

        time_in_force: Union[Unset, str] = UNSET
        if not isinstance(self.time_in_force, Unset):
            time_in_force = self.time_in_force.value

        type_: Union[Unset, str] = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        yes_price = self.yes_price

        yes_price_dollars: Union[Unset, list[int]] = UNSET
        if not isinstance(self.yes_price_dollars, Unset):
            yes_price_dollars = self.yes_price_dollars

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if action is not UNSET:
            field_dict["action"] = action
        if buy_max_cost is not UNSET:
            field_dict["buy_max_cost"] = buy_max_cost
        if client_order_id is not UNSET:
            field_dict["client_order_id"] = client_order_id
        if count is not UNSET:
            field_dict["count"] = count
        if expiration_ts is not UNSET:
            field_dict["expiration_ts"] = expiration_ts
        if no_price is not UNSET:
            field_dict["no_price"] = no_price
        if no_price_dollars is not UNSET:
            field_dict["no_price_dollars"] = no_price_dollars
        if order_group_id is not UNSET:
            field_dict["order_group_id"] = order_group_id
        if post_only is not UNSET:
            field_dict["post_only"] = post_only
        if self_trade_prevention_type is not UNSET:
            field_dict["self_trade_prevention_type"] = self_trade_prevention_type
        if sell_position_capped is not UNSET:
            field_dict["sell_position_capped"] = sell_position_capped
        if sell_position_floor is not UNSET:
            field_dict["sell_position_floor"] = sell_position_floor
        if side is not UNSET:
            field_dict["side"] = side
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if time_in_force is not UNSET:
            field_dict["time_in_force"] = time_in_force
        if type_ is not UNSET:
            field_dict["type"] = type_
        if yes_price is not UNSET:
            field_dict["yes_price"] = yes_price
        if yes_price_dollars is not UNSET:
            field_dict["yes_price_dollars"] = yes_price_dollars

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _action = d.pop("action", UNSET)
        action: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction]
        if isinstance(_action, Unset):
            action = UNSET
        else:
            action = GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestAction(_action)

        buy_max_cost = d.pop("buy_max_cost", UNSET)

        client_order_id = d.pop("client_order_id", UNSET)

        count = d.pop("count", UNSET)

        expiration_ts = d.pop("expiration_ts", UNSET)

        no_price = d.pop("no_price", UNSET)

        no_price_dollars = cast(list[int], d.pop("no_price_dollars", UNSET))

        order_group_id = d.pop("order_group_id", UNSET)

        post_only = d.pop("post_only", UNSET)

        self_trade_prevention_type = d.pop("self_trade_prevention_type", UNSET)

        sell_position_capped = d.pop("sell_position_capped", UNSET)

        sell_position_floor = d.pop("sell_position_floor", UNSET)

        _side = d.pop("side", UNSET)
        side: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide]
        if isinstance(_side, Unset):
            side = UNSET
        else:
            side = GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestSide(_side)

        ticker = d.pop("ticker", UNSET)

        _time_in_force = d.pop("time_in_force", UNSET)
        time_in_force: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce]
        if isinstance(_time_in_force, Unset):
            time_in_force = UNSET
        else:
            time_in_force = GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce(_time_in_force)

        _type_ = d.pop("type", UNSET)
        type_: Union[Unset, GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType]
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestType(_type_)

        yes_price = d.pop("yes_price", UNSET)

        yes_price_dollars = cast(list[int], d.pop("yes_price_dollars", UNSET))

        github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request = cls(
            action=action,
            buy_max_cost=buy_max_cost,
            client_order_id=client_order_id,
            count=count,
            expiration_ts=expiration_ts,
            no_price=no_price,
            no_price_dollars=no_price_dollars,
            order_group_id=order_group_id,
            post_only=post_only,
            self_trade_prevention_type=self_trade_prevention_type,
            sell_position_capped=sell_position_capped,
            sell_position_floor=sell_position_floor,
            side=side,
            ticker=ticker,
            time_in_force=time_in_force,
            type_=type_,
            yes_price=yes_price,
            yes_price_dollars=yes_price_dollars,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_create_order_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="MaintenanceWindow")


@_attrs_define
class MaintenanceWindow:
    """
    Attributes:
        end_datetime (Union[Unset, datetime.datetime]): End date and time of the maintenance window.
        start_datetime (Union[Unset, datetime.datetime]): Start date and time of the maintenance window.
    """

    end_datetime: Union[Unset, datetime.datetime] = UNSET
    start_datetime: Union[Unset, datetime.datetime] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        end_datetime: Union[Unset, str] = UNSET
        if not isinstance(self.end_datetime, Unset):
            end_datetime = self.end_datetime.isoformat()

        start_datetime: Union[Unset, str] = UNSET
        if not isinstance(self.start_datetime, Unset):
            start_datetime = self.start_datetime.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if end_datetime is not UNSET:
            field_dict["end_datetime"] = end_datetime
        if start_datetime is not UNSET:
            field_dict["start_datetime"] = start_datetime

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _end_datetime = d.pop("end_datetime", UNSET)
        end_datetime: Union[Unset, datetime.datetime]
        if isinstance(_end_datetime, Unset):
            end_datetime = UNSET
        else:
            end_datetime = isoparse(_end_datetime)

        _start_datetime = d.pop("start_datetime", UNSET)
        start_datetime: Union[Unset, datetime.datetime]
        if isinstance(_start_datetime, Unset):
            start_datetime = UNSET
        else:
            start_datetime = isoparse(_start_datetime)

        maintenance_window = cls(
            end_datetime=end_datetime,
            start_datetime=start_datetime,
        )

        maintenance_window.additional_properties = d
        return maintenance_window

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.github_com_kalshi_exchange_infra_svc_api_2_model_get_market_candlesticks_response import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse,
)
from ...types import UNSET, Response


def _get_kwargs(
    series_ticker: str,
    ticker: str,
    *,
    start_ts: int,
    end_ts: int,
    period_interval: int,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["start_ts"] = start_ts

    params["end_ts"] = end_ts

    params["period_interval"] = period_interval

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/series/{series_ticker}/markets/{ticker}/candlesticks",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    if response.status_code == 200:
        response_200 = GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    series_ticker: str,
    ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    start_ts: int,
    end_ts: int,
    period_interval: int,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    """Get Market Candlesticks

      Endpoint for getting historical candlestick data for a specific market.  Candlesticks provide OHLC
    (Open, High, Low, Close) price data aggregated over specific time intervals. Each candlestick
    represents the price movement during that period, including opening and closing prices, as well as
    the highest and lowest prices reached.  The period_interval determines the time length of each
    candlestick and must be one of: 1 (1 minute), 60 (1 hour), or 1440 (1 day). The start_ts and end_ts
    parameters define the time range for the data.

    Args:
        series_ticker (str): Series ticker - the series that contains the target market
        ticker (str): Market ticker - unique identifier for the specific market
        start_ts (int): Start timestamp (Unix timestamp). Candlesticks will include those ending
            on or after this time.
        end_ts (int): End timestamp (Unix timestamp). Candlesticks will include those ending on or
            before this time.
        period_interval (int): Time period length of each candlestick in minutes. Valid values: 1
            (1 minute), 60 (1 hour), 1440 (1 day).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]
    """

    kwargs = _get_kwargs(
        series_ticker=series_ticker,
        ticker=ticker,
        start_ts=start_ts,
        end_ts=end_ts,
        period_interval=period_interval,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    series_ticker: str,
    ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    start_ts: int,
    end_ts: int,
    period_interval: int,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    """Get Market Candlesticks

      Endpoint for getting historical candlestick data for a specific market.  Candlesticks provide OHLC
    (Open, High, Low, Close) price data aggregated over specific time intervals. Each candlestick
    represents the price movement during that period, including opening and closing prices, as well as
    the highest and lowest prices reached.  The period_interval determines the time length of each
    candlestick and must be one of: 1 (1 minute), 60 (1 hour), or 1440 (1 day). The start_ts and end_ts
    parameters define the time range for the data.

    Args:
        series_ticker (str): Series ticker - the series that contains the target market
        ticker (str): Market ticker - unique identifier for the specific market
        start_ts (int): Start timestamp (Unix timestamp). Candlesticks will include those ending
            on or after this time.
        end_ts (int): End timestamp (Unix timestamp). Candlesticks will include those ending on or
            before this time.
        period_interval (int): Time period length of each candlestick in minutes. Valid values: 1
            (1 minute), 60 (1 hour), 1440 (1 day).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse
    """

    return sync_detailed(
        series_ticker=series_ticker,
        ticker=ticker,
        client=client,
        start_ts=start_ts,
        end_ts=end_ts,
        period_interval=period_interval,
    ).parsed


async def asyncio_detailed(
    series_ticker: str,
    ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    start_ts: int,
    end_ts: int,
    period_interval: int,
) -> Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    """Get Market Candlesticks

      Endpoint for getting historical candlestick data for a specific market.  Candlesticks provide OHLC
    (Open, High, Low, Close) price data aggregated over specific time intervals. Each candlestick
    represents the price movement during that period, including opening and closing prices, as well as
    the highest and lowest prices reached.  The period_interval determines the time length of each
    candlestick and must be one of: 1 (1 minute), 60 (1 hour), or 1440 (1 day). The start_ts and end_ts
    parameters define the time range for the data.

    Args:
        series_ticker (str): Series ticker - the series that contains the target market
        ticker (str): Market ticker - unique identifier for the specific market
        start_ts (int): Start timestamp (Unix timestamp). Candlesticks will include those ending
            on or after this time.
        end_ts (int): End timestamp (Unix timestamp). Candlesticks will include those ending on or
            before this time.
        period_interval (int): Time period length of each candlestick in minutes. Valid values: 1
            (1 minute), 60 (1 hour), 1440 (1 day).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]
    """

    kwargs = _get_kwargs(
        series_ticker=series_ticker,
        ticker=ticker,
        start_ts=start_ts,
        end_ts=end_ts,
        period_interval=period_interval,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    series_ticker: str,
    ticker: str,
    *,
    client: Union[AuthenticatedClient, Client],
    start_ts: int,
    end_ts: int,
    period_interval: int,
) -> Optional[GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse]:
    """Get Market Candlesticks

      Endpoint for getting historical candlestick data for a specific market.  Candlesticks provide OHLC
    (Open, High, Low, Close) price data aggregated over specific time intervals. Each candlestick
    represents the price movement during that period, including opening and closing prices, as well as
    the highest and lowest prices reached.  The period_interval determines the time length of each
    candlestick and must be one of: 1 (1 minute), 60 (1 hour), or 1440 (1 day). The start_ts and end_ts
    parameters define the time range for the data.

    Args:
        series_ticker (str): Series ticker - the series that contains the target market
        ticker (str): Market ticker - unique identifier for the specific market
        start_ts (int): Start timestamp (Unix timestamp). Candlesticks will include those ending
            on or after this time.
        end_ts (int): End timestamp (Unix timestamp). Candlesticks will include those ending on or
            before this time.
        period_interval (int): Time period length of each candlestick in minutes. Valid values: 1
            (1 minute), 60 (1 hour), 1440 (1 day).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GithubComKalshiExchangeInfraSvcApi2ModelGetMarketCandlesticksResponse
    """

    return (
        await asyncio_detailed(
            series_ticker=series_ticker,
            ticker=ticker,
            client=client,
            start_ts=start_ts,
            end_ts=end_ts,
            period_interval=period_interval,
        )
    ).parsed



from enum import Enum


class GithubComKalshiExchangeInfraSvcApi2ModelAcceptQuoteRequestAcceptedSide(str, Enum):
    NO = "no"
    YES = "yes"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item_market_result import (
    GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItem")


@_attrs_define
class GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItem:
    """
    Attributes:
        market_result (Union[Unset,
            GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult]): The outcome of the
            market settlement ('yes' or 'no').
        no_count (Union[Unset, int]): Number of NO contracts owned at the time of settlement.
        no_total_cost (Union[Unset, int]):
        revenue (Union[Unset, int]):
        settled_time (Union[Unset, Any]):
        ticker (Union[Unset, str]): The ticker symbol of the market that was settled.
        yes_count (Union[Unset, int]): Number of YES contracts owned at the time of settlement.
        yes_total_cost (Union[Unset, int]):
    """

    market_result: Union[
        Unset, GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult
    ] = UNSET
    no_count: Union[Unset, int] = UNSET
    no_total_cost: Union[Unset, int] = UNSET
    revenue: Union[Unset, int] = UNSET
    settled_time: Union[Unset, Any] = UNSET
    ticker: Union[Unset, str] = UNSET
    yes_count: Union[Unset, int] = UNSET
    yes_total_cost: Union[Unset, int] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        market_result: Union[Unset, str] = UNSET
        if not isinstance(self.market_result, Unset):
            market_result = self.market_result.value

        no_count = self.no_count

        no_total_cost = self.no_total_cost

        revenue = self.revenue

        settled_time = self.settled_time

        ticker = self.ticker

        yes_count = self.yes_count

        yes_total_cost = self.yes_total_cost

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if market_result is not UNSET:
            field_dict["market_result"] = market_result
        if no_count is not UNSET:
            field_dict["no_count"] = no_count
        if no_total_cost is not UNSET:
            field_dict["no_total_cost"] = no_total_cost
        if revenue is not UNSET:
            field_dict["revenue"] = revenue
        if settled_time is not UNSET:
            field_dict["settled_time"] = settled_time
        if ticker is not UNSET:
            field_dict["ticker"] = ticker
        if yes_count is not UNSET:
            field_dict["yes_count"] = yes_count
        if yes_total_cost is not UNSET:
            field_dict["yes_total_cost"] = yes_total_cost

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _market_result = d.pop("market_result", UNSET)
        market_result: Union[
            Unset, GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult
        ]
        if isinstance(_market_result, Unset):
            market_result = UNSET
        else:
            market_result = GithubComKalshiExchangeInfraSvcApi2ModelGetSettlementsResponseSettlementsItemMarketResult(
                _market_result
            )

        no_count = d.pop("no_count", UNSET)

        no_total_cost = d.pop("no_total_cost", UNSET)

        revenue = d.pop("revenue", UNSET)

        settled_time = d.pop("settled_time", UNSET)

        ticker = d.pop("ticker", UNSET)

        yes_count = d.pop("yes_count", UNSET)

        yes_total_cost = d.pop("yes_total_cost", UNSET)

        github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item = cls(
            market_result=market_result,
            no_count=no_count,
            no_total_cost=no_total_cost,
            revenue=revenue,
            settled_time=settled_time,
            ticker=ticker,
            yes_count=yes_count,
            yes_total_cost=yes_total_cost,
        )

        github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item.additional_properties = d
        return github_com_kalshi_exchange_infra_svc_api_2_model_get_settlements_response_settlements_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_maintenance_windows_item import (
        GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem,
    )
    from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_standard_hours_item import (
        GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem,
    )


T = TypeVar("T", bound="GithubComKalshiExchangeInfraCommonExchangeMetadataSchedule")


@_attrs_define
class GithubComKalshiExchangeInfraCommonExchangeMetadataSchedule:
    """
    Attributes:
        maintenance_windows (Union[Unset,
            list['GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem']]): Scheduled
            maintenance windows, during which the exchange may be unavailable.
        standard_hours (Union[Unset,
            list['GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem']]): The standard operating
            hours of the exchange. All times are expressed in ET. Outside of these times trading will be unavailable.
    """

    maintenance_windows: Union[
        Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem"]
    ] = UNSET
    standard_hours: Union[
        Unset, list["GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem"]
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        maintenance_windows: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.maintenance_windows, Unset):
            maintenance_windows = []
            for maintenance_windows_item_data in self.maintenance_windows:
                maintenance_windows_item = maintenance_windows_item_data.to_dict()
                maintenance_windows.append(maintenance_windows_item)

        standard_hours: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.standard_hours, Unset):
            standard_hours = []
            for standard_hours_item_data in self.standard_hours:
                standard_hours_item = standard_hours_item_data.to_dict()
                standard_hours.append(standard_hours_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if maintenance_windows is not UNSET:
            field_dict["maintenance_windows"] = maintenance_windows
        if standard_hours is not UNSET:
            field_dict["standard_hours"] = standard_hours

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_maintenance_windows_item import (
            GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem,
        )
        from ..models.github_com_kalshi_exchange_infra_common_exchange_metadata_schedule_standard_hours_item import (
            GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem,
        )

        d = dict(src_dict)
        maintenance_windows = []
        _maintenance_windows = d.pop("maintenance_windows", UNSET)
        for maintenance_windows_item_data in _maintenance_windows or []:
            maintenance_windows_item = (
                GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleMaintenanceWindowsItem.from_dict(
                    maintenance_windows_item_data
                )
            )

            maintenance_windows.append(maintenance_windows_item)

        standard_hours = []
        _standard_hours = d.pop("standard_hours", UNSET)
        for standard_hours_item_data in _standard_hours or []:
            standard_hours_item = GithubComKalshiExchangeInfraCommonExchangeMetadataScheduleStandardHoursItem.from_dict(
                standard_hours_item_data
            )

            standard_hours.append(standard_hours_item)

        github_com_kalshi_exchange_infra_common_exchange_metadata_schedule = cls(
            maintenance_windows=maintenance_windows,
            standard_hours=standard_hours,
        )

        github_com_kalshi_exchange_infra_common_exchange_metadata_schedule.additional_properties = d
        return github_com_kalshi_exchange_infra_common_exchange_metadata_schedule

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GithubComKalshiExchangeInfraSvcApi2ModelCreateOrderRequestTimeInForce(str, Enum):
    FILL_OR_KILL = "fill_or_kill"
    IMMEDIATE_OR_CANCEL = "immediate_or_cancel"

    def __str__(self) -> str:
        return str(self.value)
